-- file: rc3.lua
-- print bass-treble audio control tone resistors and caps --
-- 2024-jul-22

print("  --Example 2.14.2  Active Tone Control development--" )
print("  --From the National Handbook--" )

--[[  Description:

  Example 2.14.2  Active Tone Control development

  Design a bass and treble active tone control circuit having ±20dB
  gain (Avb) with low frequency upper 3dB corner at 30 Hz (fL) and high
  frequency upper 3dB corner at 10kHz (fH). Some of the functions here
  are used in the 4562 specification data sheet example.

]]--

MICRO = (1e6)  -- for microfarad caps
NANO = (1e9)	-- for nanofarad caps
PICO = (1e12)	-- for picofarad caps
PI2 = 2 * math.pi

--Solution BASS DESIGN:

-------------------------------------------------------------------
--#1. Select R2 = 1OOk (linear pot). (will use 10k next version)
R2=100000
fL = 30		-- required for 3db corner
fH = 10000	-- required for upper corner
Avb = 10	-- 10 required for 20db max gain

-------------------------------------------------------------------
--#2. From Equation (2.14.13), (2.14.14):
-- 2.14.13:  Avb = (R1+R2)/R1		.. max bass boost
-- 2.14.14:  1/Avb = R1 / (R1+R2)     	.. max bass cut
-- Since Avb = 1 + R2/R1
R1 = R2 / (Avb-1)
print("R1=", R1)
print("R2=", R2, "bass pot")

-------------------------------------------------------------------
--#3 Given fL=30Hz and from 2.14.22 and 2.14.18 --
-- 2.14.22:  fLB / fL = fH / fHB  ..(gain=10 since +20db)
-- 2.14.18:  C1 = 1/(6.28 * fLB * R1)
fLB =Avb*fL
C1 = MICRO/(PI2 * fLB * R1)
print("C1=",C1, "uf")

-------------------------------------------------------------------
--#4.  Solution: TREBLE DESIGN
-- Let R5=R1 (carries the bass boost/cut to mix with C3)
R5=R1
print("R5=",R5)

-------------------------------------------------------------------
--#5. From Equation (2.14.15):
-- 2.14.15:  Avt = (R3+R1+2*R5)/R3	        ..max treble boost
--Since Avt = (R1+R3+2*R5)/R3, refactor to get R3 
R3 = (R1 + 2*R5)/(Avb-1)      --assuming Avt==Avb
print("R3=",R3)

-------------------------------------------------------------------
--#6. Given fH = 10kHz and from Equation (2.14.20):
C3 = MICRO/(PI2 * fH * R3)
print("C3=",C3, "uf" )

-------------------------------------------------------------------
--#7. From Equation (2.14.17):  R4 must be greater ...
R4 = 1 * ( R3 + R1 + 2*R5)
-- R4 = R4 * 10  -- don't know why Handbook multiplies sum by 10??
print("R4=",R4, "..treble pot minimum" )

-------------------------------------------------------------------
print("\n Print abstract results for 2.14.13a on page 58, 2-45...")

_fL = MICRO/(PI2 * R2 * C1)
print("_fL=",_fL, "hz" )

_fLB = MICRO/(PI2 * R1 * C1)
print("_fLB=",_fLB, "hz" )

_Avb = 1 + R2/R1
print("_Avb=",_Avb, "units" )

_fH = MICRO/(PI2 * R3 * C3)
print("_fH=", _fH, "hz")

_fHB = MICRO/(PI2 * (R1+R3+2*R5)*C3)
print("_fHB=", _fHB, "hz")

_Avt = 1 + (R1 + 2*R5)/R3
print("_Avt=", _Avt, "units")


-------------------------------------------------------------------
print("\n Print results again after overide with practical value...")

R1=11000 -- was 11111.11111
C1=0.05  -- was .04776 uf
R3=3700  -- was 3703 so insignificant difference
C3=.005  -- was .00429 uf
R5=R1

_fL = MICRO/(PI2 * R2 * C1)
print("_fL=",_fL, "hz" )

_fLB = MICRO/(PI2 * R1 * C1)
print("_fLB=",_fLB, "hz" )

_Avb = 1 + R2/R1
print("_Avb=",_Avb, "units" )

_fH = MICRO/(PI2 * R3 * C3)
print("_fH=", _fH, "hz")

_fHB = MICRO/(PI2 * (R1+R3+2*R5)*C3)
print("_fHB=", _fHB, "hz")

_Avt = 1 + (R1 + 2*R5)/R3
print("_Avt=", _Avt, "units")

--[[  ################# Notes ###############

The printed R-C values are the best results that can be calculated by
the math model employed by the Handbook.  They can be replaced by the
nearest practical value. For example, R3 = 3703.7 so use 3600.
....

Equations (2.14.15) and (2.14.16) are best understood by recognizing
that the bass circuit at high frequencies forms a wye·connected load
across the treble circuit. By doing a wye·delta transformation (see
Appendix A3), the effective loading resistor is found to be (R1 + 2R5)
which is in parallel with (R3 + R4) and dominates the expression. (See
Figure 2.14.13b.) This defines a constraint upon R4 which is expressed
as Equation (2.14.17).

The treble pot in 2.14.17 needs to be larger than the bass pot.
... ( false:  there is no evidence to support this claim )

2.14.13:  Avb = (R1+R2)/R1		.. max bass boost
2.14.14:  1/Avb = R1 / (R1+R2)     	.. max bass cut
2.14.15:  Avt = (R3+R1+2*R5)/R3	        ..max treble boost
2.14.16:  1/Avt = R3 / (R3+R1+2*R5)	..max treble cut
2.14.17:  R4 >= 10 * (R3+R1+2*R5)       ..do not multiply by 10!
2.14.18:  C1 = 1/(6.28 * fLB * R1)
2.14.19:  R2 = 1/(6.28 * fL * C1) 
2.14.20:  C3 = 1/(6.28 * fH * R3)
2.14.21:  R5 = 0.5 * 1/(6.28 * fHB * C3) - R1 - R3)
2.14.22:  (fLB / fL) || (fH / fHB)  ~= 10  ..(since +20db)

 ]]--
